package com.ruoyi.web.controller.app;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.ServiceConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.AsArticleClassify;
import com.ruoyi.common.core.domain.entity.EUser;
import com.ruoyi.common.core.domain.entity.EUserVO;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.verify.vo.IDResponse;
import com.ruoyi.common.utils.wx.vo.PrepayResponseVO;
import com.ruoyi.framework.web.service.TokenService;
import com.ruoyi.system.domain.EFeedback;
import com.ruoyi.system.domain.EShareKey;
import com.ruoyi.system.domain.EtArticle;
import com.ruoyi.system.domain.changeBalance.EChangeBalance;
import com.ruoyi.system.domain.changeBalance.EChangeBalanceQuery;
import com.ruoyi.system.domain.channel.ChannelVO;
import com.ruoyi.system.domain.channelWithdraw.ChannelWithdrawQuery;
import com.ruoyi.system.domain.channelWithdraw.ChannelWithdrawVO;
import com.ruoyi.system.order.domain.EOrder;
import com.ruoyi.system.order.domain.EOrderQuery;
import com.ruoyi.system.order.domain.EOrderVO;
import com.ruoyi.system.domain.query.AuthenticationQuery;
import com.ruoyi.system.domain.rule.EFeeRule;
import com.ruoyi.system.domain.vo.IndexAdminVo;
import com.ruoyi.system.domain.withdraw.EWithdrawQuery;
import com.ruoyi.system.model.service.IEModelService;
import com.ruoyi.system.order.service.IEOrderService;
import com.ruoyi.system.service.*;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.support.TransactionTemplate;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.List;

/**
 * app接口（需要登录校验的）
 *  校验
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/appVerify")
public class AppVerifyController extends BaseController
{

    @Resource
    private IEUserService userService;

    @Resource
    private IEOrderService orderService;

//    @Autowired
//    private IEDeviceService deviceService;

    @Autowired
    private IEWithdrawService withdrawService;

    @Autowired
    private TokenService tokenService;

    @Autowired
    private EChannelService channelService;

    @Autowired
    private IWxPayService wxPayService;

    @Autowired
    private IEModelAccessoryService modelAccessoryService;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private IEOrderOperService orderOperService;

    @Autowired
    private IEShareKeyService shareKeyService;

    @Resource
    private IAsFeedbackService feedbackService;

    @Autowired
    private IEUserWithdrawService userWithdrawService;

    @Autowired
    private EChannelWithdrawService etChannelWithdrawService;

    @Autowired
    private ISysDictDataService dictDataService;

    @Autowired
    private IEFeeRuleService feeRuleService;

    @Autowired
    private IEModelService modelService;

    @Autowired
    private IEArticleService articleService;

    @Autowired
    private IEArticleClassifyService articleClassifyService;

    /**
     * 首页统计
     */
    @GetMapping(value = {  "/index" })
    public AjaxResult index(String startTime,String endTime)
    {
        logger.info("【首页统计/index】参数：startTime={},endTime={}", startTime,endTime);
        AjaxResult ajax = AjaxResult.success();
        IndexAdminVo incomeVos = orderService.indexStatistics(startTime, endTime,getUserId());
        ajax.put(AjaxResult.DATA_TAG, incomeVos);
        return ajax;
    }

    /**
     * 实名认证
     */
    @Log(title = "实名认证", businessType = BusinessType.AUTHENTICATION)
    @GetMapping("/user/authentication")
    public AjaxResult authentication(AuthenticationQuery authenticationQuery)
    {
        logger.info("【实名认证】请求参数：authenticationQuery={}", JSON.toJSON(authenticationQuery));
        Object authentication = userService.authentication(authenticationQuery);
        //判断o是否是字符串
        if(authentication instanceof String){
            return AjaxResult.error((String) authentication);
        }else{
            IDResponse.Result result = (IDResponse.Result)authentication;
            if(result.getIsok()){
                //保存身份信息
                // 更新用户并更新缓存
                LoginUser loginUser = SecurityUtils.getLoginUser();
                EUser asUser = new EUser();
                asUser.setUserId(authenticationQuery.getUserId());
                asUser.setRealName(authenticationQuery.getRealName());
                asUser.setIdCard(authenticationQuery.getIdCard());
                asUser.setIsAuthentication(true);
                asUser.setPhonenumber(authenticationQuery.getPhone());
                int updateUser = userService.updateUser(asUser);
                if (updateUser>0)
                {
                    logger.info("【实名认证】保存身份信息成功");
                    // 更新缓存用户信息
                    tokenService.setLoginUser(loginUser);
                }
            }
            return AjaxResult.success(authentication);
        }
    }

    /**
     * 确认支付
     */
    @Log(title = "确认支付", businessType = BusinessType.CONFIRMPAY)
    @PostMapping("/confirmPay")
    public AjaxResult confirmPay(String orderNo)
    {
        logger.info("【确认支付】请求参数：orderNo={}",orderNo);
        PrepayResponseVO orderServiceOrder = orderService.confirmPay(orderNo);
        return success(orderServiceOrder);
    }

    /**
     * 订单列表
     */
    @GetMapping("/orderList")
    public AjaxResult orderList(EOrderQuery order)
    {
        logger.info("订单列表请求：order=【"+JSON.toJSONString(order)+"】");
        List<EOrderVO> rlOrderVOS = orderService.selectRlOrderList(order);
        return success(rlOrderVOS);
    }

    /**
     * 我的订单列表
     */
    @GetMapping("/myOrderList")
    public AjaxResult myOrderList(String[] statusList)
    {
        logger.info("订单列表请求：statusList=【"+JSON.toJSONString(statusList)+"】");
        EOrderQuery order = new EOrderQuery();
        order.setUserId(getUserId());
        if(statusList.length == 0){
            statusList = null;
        }
        order.setStatusList(statusList);
        List<EOrderVO> rlOrderVOS = orderService.selectRlOrderListNoIsolate(order);
        return success(rlOrderVOS);
    }

    /**
     * 订单信息
     */
    @GetMapping("/orderInfo")
    public AjaxResult orderInfo(String orderNo)
    {
        logger.info("订单列表请求：order=【"+JSON.toJSON(orderNo)+"】");
        EOrderVO rlOrder = orderService.getOrderInfoByOrderNo(orderNo);
        return success(rlOrder);
    }

//    /**
//     * 扫码绑定车辆
//     */
//    @Log(title = "扫码绑定车辆", businessType = BusinessType.BANDDEVICE)
//    @PostMapping("/bandDevice")
//    public AjaxResult bandDevice(String orderNo, String sn)
//    {
//        logger.info("扫码绑定车辆：orderNo=【"+orderNo+"】,sn=【"+sn+"】");
//        orderService.bandDevice(orderNo,sn);
//        return success();
//    }

    /**
     * 用户扫码绑定车辆
     */
    @Log(title = "用户扫码绑定车辆", businessType = BusinessType.BANDDEVICE)
    @PostMapping("/userBandDevice")
    public AjaxResult userBandDevice(String sn)
    {
        logger.info("扫码绑定车辆：sn=【"+sn+"】");
        if(StrUtil.isBlank(sn)){
            throw new ServiceException("设备sn不能为空");
        }
        int i = orderService.userBandDevice(getUserId(),sn);
        if(i<=0){
            return AjaxResult.error("绑定失败");
        }
        return success(i);
    }

//    /**
//     * 临时锁车
//     */
//    @Log(title = "临时锁车", businessType = BusinessType.LOCK)
//    @PostMapping("/device/lock")
//    public AjaxResult deviceLock(String sn,String orderNo,String isBluetooth,String lon,String lat)
//    {
//        logger.info("【临时锁车请求参数】：{},订单号：{},是否蓝牙控制：{}", sn,orderNo,isBluetooth);
//        Boolean i =deviceService.lock(sn,orderNo,isBluetooth,lon,lat);
//        return success(i);
//    }

//    /**
//     * 临时解锁
//     */
//    @Log(title = "临时解锁", businessType = BusinessType.UNLOCK)
//    @PostMapping("/device/unlock")
//    public AjaxResult deviceUnlock(String sn,String orderNo,String isBluetooth,String lon,String lat)
//    {
//        logger.info("【临时解锁请求参数】：{},订单号：{},是否蓝牙控制：{}", sn,orderNo,isBluetooth);
//        if(StrUtil.isBlank(orderNo)){
//            throw new ServiceException("订单号为空");
//        }
//        Boolean i =deviceService.unlock(sn,orderNo,isBluetooth,lon,lat);
//        return success(i);
//    }

//    /**
//     * 修改车辆
//     */
//    @Log(title = "修改车辆", businessType = BusinessType.UPDATE)
//    @PutMapping("/device/edit")
//    public AjaxResult deviceEdit2(@RequestBody EDeviceQuery deviceQuery)
//    {
//        logger.info("【修改车辆】请求参数：device={}", JSON.toJSONString(deviceQuery));
//        if(StrUtil.isBlank(deviceQuery.getSn())){
//            return error("【修改车辆】sn不能为空");
//        }
//        EDevice rlDevice = deviceService.selectEDeviceBySn(deviceQuery.getSn());
//        if(rlDevice == null){
//            return error("【修改车辆】设备不存在【"+deviceQuery.getSn()+"】");
//        }
//        return toAjax(deviceService.updateEDeviceBySn(deviceQuery));
//    }


    /**
     * 续单
     */
    @Log(title = "续单", businessType = BusinessType.RELET)
    @PostMapping("/relet")
    public AjaxResult relet(@RequestBody EOrderQuery orderQuery)
    {
        logger.info("【续单】请求参数：order={}", JSON.toJSONString(orderQuery));
        orderService.validate(orderQuery);
        PrepayResponseVO responseVO =orderService.relet(orderQuery);
        return success(responseVO);
    }

//    /**
//     * 还车
//     */
//    @Log(title = "还车", businessType = BusinessType.RETURN_VEHICLE)
//    @PostMapping("/returnVehicle")
//    public AjaxResult returnVehicle(@RequestBody EOrderQuery order)
//    {
//        logger.info("【还车】请求参数：order={}", JSON.toJSONString(order));
//        Boolean aBoolean = deviceService.returnVehicle(order);
//        return success(aBoolean);
//    }

    /**
     * 订单取消
     */
    @Log(title = "订单取消", businessType = BusinessType.ORDERCANCEL)
    @PostMapping("/orderCancel")
    public AjaxResult orderCancel(String orderNo)
    {
        logger.info("【订单取消】请求参数：orderNo={}", orderNo);
        Boolean aBoolean = orderService.orderCancel(orderNo);
        return success(aBoolean);
    }


    /**
     * 获取提现记录详细信息
     */
    @GetMapping(value = "/withdraw/{id}")
    public AjaxResult withdrawInfo(@PathVariable("id") Long id)
    {
        return success(withdrawService.selectRlWithdrawById(id));
    }

    /**
     * 我的账户
     */
    @GetMapping(value = {  "/myAccountInfo" })
    public AjaxResult myAccountInfo()
    {
        AjaxResult ajax = AjaxResult.success();
        EUserVO rlUser = userService.myAccountInfoByUserId(getUserId());
        ajax.put(AjaxResult.DATA_TAG, rlUser);
        return ajax;
    }

    /**
     * 账变记录
     */
    @GetMapping(value = {  "/myChangeBalanceList" })
    public AjaxResult myChangeBalanceList(EChangeBalanceQuery query)
    {
        logger.info("【账变记录/myChangeBalanceList】参数：【query={}】", query);
        AjaxResult ajax = AjaxResult.success();
        if(ObjectUtil.isNotNull(query.getType()) && query.getType().equals("0")){
            query.setType(null);
        }
        List<EChangeBalance> changeBalances  = userService.myChangeBalanceList(query,getUserId());
        ajax.put(AjaxResult.DATA_TAG, changeBalances);
        return ajax;
    }


//    /**
//     * 改价
//     */
//    @Log(title = "订单改价", businessType = BusinessType.EDITPRICE)
//    @PutMapping("/order/changePrice")
//    public AjaxResult orderEdit(@RequestBody EOrderQuery order)
//    {
//        logger.info("【订单改价信息】：{}", JSON.toJSON(order));
//        //根据订单号查询订单信息
//        EOrder etOrder1 = orderService.selectRlOrderByOrderNo(order.getOrderNo());
//        if(ObjectUtil.isNull(etOrder1)){
//            throw new ServiceException("订单不存在");
//        }
//        if(ServiceConstants.ORDER_PAY_STATUS_PAID.equals(etOrder1.getPaid())){
//            throw new ServiceException("订单已支付，不能改价");
//        }
//        if(!ServiceConstants.ORDER_STATUS_TO_BE_PAID.equals(etOrder1.getStatus())){
//            throw new ServiceException("非待支付订单无法改价");
//        }
//        String outTradeNo = etOrder1.getOutTradeNo();
//        ChannelVO channelVO = channelService.selectSmChannelByChannelId(etOrder1.getPayChannel());
//        Boolean execute = transactionTemplate.execute(e -> {
//            if(StrUtil.isNotBlank(outTradeNo)){
//                /** 关闭未支付订单 */
//                if(wxPayService.closeOrder(outTradeNo,channelVO)){
//                    throw new ServiceException("关闭未支付订单失败");
//                }
//                logger.info("【订单改价】订单【{}】,有outTradeNo = 【{}】,查询订单未支付，关闭订单：{}", etOrder1.getOrderNo(),outTradeNo);
//                BigDecimal payFee = BigDecimal.ZERO;
//                if(ObjectUtil.isNotNull(order.getPayFee())){
//                    payFee = payFee.add(order.getPayFee());
//                }
//                order.setPayFee(payFee);
//                /** 更新订单信息 */
//                int i = orderService.updateRlOrderByOrderNo(order);
//                if(i == 0){
//                    throw new ServiceException("【改价】更新订单信息失败");
//                }
//                /** 记录订单履历 */
//                if(!orderOperService.recordOrderHistory(order.getOrderNo(),ServiceConstants.ORDER_OPERATION_CHANGE_PRICE,
//                        etOrder1.getStatus(),order.getStatus(),etOrder1.getPayFee(),order.getPayFee(),etOrder1.getUserId(),etOrder1.getPhone(),
//                        "订单改价,修改前价格："+etOrder1.getPayFee()+",修改后价格："+order.getPayFee())){
//                    throw new ServiceException("【改价】更新订单信息失败");
//                }
//            }
//            return Boolean.TRUE;
//        });
//        if(!execute)throw new ServiceException("【改价】失败");
//        return toAjax(1);
//    }


    /**
     * 根据sn查询正在进行中的订单
     */
    @GetMapping("/getInProgressOrder")
    public AjaxResult getInProgressOrder(String sn)
    {
        logger.info("【根据sn查询正在进行中的订单】：sn=【{}】", sn);
        if(StrUtil.isBlank(sn)){
            throw new ServiceException("【根据sn查询正在进行中的订单】sn不能为空");
        }
        EOrderVO order = orderService.getInProgressOrder(sn);
        return success(order);
    }

    /**
     * 根据归属用户id查询共享钥匙列表(正常)
     */
    @GetMapping("/getKeyListByOwnerId")
    public AjaxResult getKeyListByOwnerId()
    {
        logger.info("【根据归属用户id查询共享钥匙列表】");
        List<EShareKey> eShareKeys = shareKeyService.selectEShareKeyListByOwnerId(getUserId());
        return success(eShareKeys);
    }

    /**
     * 根据归属用户id查询共享钥匙列表(已失效)
     */
    @GetMapping("/getExpiredKeyListByOwnerId")
    public AjaxResult getExpiredKeyListByOwnerId()
    {
        logger.info("【根据归属用户id查询共享钥匙列表(已失效)】");
        List<EShareKey> eShareKeys = shareKeyService.selectExpiredEShareKeyListByOwnerId(getUserId());
        return success(eShareKeys);
    }

    /**
     * 添加共享钥匙
     */
    @Log(title = "共享钥匙", businessType = BusinessType.INSERT)
    @PostMapping("/addKey")
    public AjaxResult addKey(@RequestBody EShareKey eShareKey)
    {
        logger.info("【添加共享钥匙】：【{}】", eShareKey);
        if(StrUtil.isBlank(eShareKey.getSharePhone())){
            return error("【添加共享钥匙】分享人电话不能为空");
        }
        if(eShareKey.getExpirationTime() == null){
            return error("【添加共享钥匙】有效时间不能为空");
        }
        // 赋值
        if (assign(eShareKey)) return error("【添加共享钥匙】分享人不存在");
        // 根据有效期字段填写到期时间
        return toAjax(shareKeyService.insertEShareKey(eShareKey));
    }

    private boolean assign(EShareKey eShareKey) {
        EUserVO eUserVO = userService.selectUserByUserName(eShareKey.getSharePhone());
        if(eUserVO == null){
            return true;
        }
        eShareKey.setShareId(eUserVO.getUserId());
        eShareKey.setCreateBy(getUsername());
        eShareKey.setOwnerId(getUserId());
        eShareKey.setOwnerPhone(getUsername());
        eShareKey.setOwnerName(getUsername());
        return false;
    }

    /**
     * 修改共享钥匙
     */
    @Log(title = "共享钥匙", businessType = BusinessType.UPDATE)
    @PutMapping("/editKey")
    public AjaxResult editKey(@RequestBody EShareKey eShareKey)
    {
        logger.info("【修改共享钥匙】：【{}】", JSON.toJSONString(eShareKey));
        return toAjax(shareKeyService.updateEShareKey(eShareKey));
    }

    /**
     * 删除共享钥匙
     */
    @Log(title = "共享钥匙", businessType = BusinessType.DELETE)
    @DeleteMapping("/del/{keyIds}")
    public AjaxResult removeKey(@PathVariable Long[] keyIds)
    {
        logger.info("【删除共享钥匙】：【{}】", JSON.toJSONString(keyIds));
        for (Long keyId: keyIds) {
            EShareKey eShareKey = new EShareKey();
            eShareKey.setKeyId(keyId);
            eShareKey.setDelFlag("1");
            int i = shareKeyService.updateEShareKey(eShareKey);
            if (i == 0) return AjaxResult.warn("【共享钥匙】删除失败");
        }
        return toAjax(1);
    }

    /**
     * 新增反馈意见
     */
    @Log(title = "反馈意见", businessType = BusinessType.INSERT)
    @PostMapping("/feedback")
    public AjaxResult add(@RequestBody EFeedback asFeedback)
    {
        logger.info("【新增反馈意见】：【{}】", JSON.toJSONString(asFeedback));
        //校验请求参数
        if(StrUtil.isBlank(asFeedback.getType())){
            return error("类型不能为空");
        }
        if(StrUtil.isBlank(asFeedback.getIssueDescription())){
            return error("问题描述不能为空");
        }
        if(StrUtil.isBlank(asFeedback.getContactInfo())){
            return error("联系方式不能为空");
        }
        return toAjax(feedbackService.insertAsFeedback(asFeedback));
    }

    /**
     * 管理员提现
     */
    @Log(title = "管理员提现", businessType = BusinessType.ADMINWITHDRAW)
    @PostMapping("/admin/withdraw")
    public AjaxResult add(@RequestBody EWithdrawQuery withdraw)
    {
        logger.info("管理员提现请求：【{}】", JSON.toJSON(withdraw));
        int i = userService.adminWithdraw(withdraw);
        return toAjax(i);
    }

    /**
     * 修改手机号
     */
    @Log(title = "修改手机号", businessType = BusinessType.ADMINWITHDRAW)
    @PostMapping("/edit/phone")
    public AjaxResult editPhone(String phone)
    {
        logger.info("修改手机号：【phone={}】", phone);
        EUser updateUser = new EUser();
        updateUser.setUserId(getUserId());
        updateUser.setPhonenumber(phone);
        int i = userService.updateUser(updateUser);
        if(i == 0) return AjaxResult.warn("修改手机号失败");
        return toAjax(i);
    }


    /**
     *  根据token获取提现渠道的列表
     */
    @GetMapping("/getUserWithdrawChannelList")
    public AjaxResult getUserWithdrawChannelList()
    {
        logger.info("根据token获取提现渠道列表：【userId="+getUserId()+"】");
        return AjaxResult.success(userWithdrawService.selectRlUserWithdrawListByUserId(getUserId()));
    }

    /**
     * 查询全局提现渠道列表
     */
    @GetMapping("/withdrawList")
    public AjaxResult withdrawList(ChannelWithdrawQuery query)
    {
        List<ChannelWithdrawVO> list = etChannelWithdrawService.selectChannelWithdrawList(query);
        return success(list);
    }

    /**
     * 获取字典类型列表
     */
    @GetMapping("/getDictData")
    public AjaxResult getDictData(String dictType)
    {
        SysDictData sysDictData = new SysDictData();
        sysDictData.setDictType(dictType);
        List<SysDictData> list = dictDataService.selectDictDataList(sysDictData);
        return success(list);
    }

//    /**
//     * 查询收费模板列表
//     */
//    @GetMapping("/ruleList")
//    public AjaxResult ruleList(EFeeRule rlFeeRule)
//    {
//        List<EFeeRule> list = feeRuleService.selectRlFeeRuleList(rlFeeRule);
//        return success(list);
//    }

    /**
     * 新增收费模板
     */
    @Log(title = "收费模板", businessType = BusinessType.INSERT)
    @PostMapping("/rule")
    public AjaxResult addRule(@RequestBody EFeeRule rlFeeRule)
    {
        logger.info("新增收费模板：【{}】", JSON.toJSONString(rlFeeRule));
        return toAjax(feeRuleService.insertEFeeRule(rlFeeRule));
    }

    /**
     * 修改收费模板
     */
    @Log(title = "收费模板", businessType = BusinessType.UPDATE)
    @PutMapping("/rule")
    public AjaxResult editRule(@RequestBody EFeeRule rlFeeRule)
    {
        logger.info("修改收费模板：【{}】", JSON.toJSONString(rlFeeRule));
        return toAjax(feeRuleService.updateEFeeRule(rlFeeRule));
    }

    /**
     * 删除收费模板(逻辑删除)
     */
    @Log(title = "收费模板", businessType = BusinessType.DELETE)
    @DeleteMapping("/rule/{ruleIds}")
    public AjaxResult removeRule(@PathVariable Long[] ruleIds)
    {
        logger.info("删除收费模板：【{}】", JSON.toJSONString(ruleIds));
        for (Long ruleId : ruleIds){
            EFeeRule eFeeRule = new EFeeRule();
            eFeeRule.setDelFlag("1");
            eFeeRule.setRuleId(ruleId);
            int i = feeRuleService.updateEFeeRule(eFeeRule);
            if(i == 0){
                return AjaxResult.warn("【收费模板】删除失败");
            }
        }
        return toAjax(1);
    }

//    /**
//     * 查询车辆型号列表
//     */
//    @GetMapping("/modelList")
//    public AjaxResult modelList(EModelQuery eModel)
//    {
//        logger.info("查询车辆型号列表：【{}】", JSON.toJSONString(eModel));
//        List<EModelVO> list = modelService.selectEModelList(eModel);
//        return success(list);
//    }
//
//    /**
//     * 新增车辆型号
//     */
//    @Log(title = "车辆型号", businessType = BusinessType.INSERT)
//    @PostMapping("/model")
//    public AjaxResult addModel(@RequestBody EModel eModel)
//    {
//        logger.info("新增车辆型号：【{}】", JSON.toJSONString(eModel));
//        return toAjax(modelService.insertEModel(eModel));
//    }

//    /**
//     * 修改车辆型号
//     */
//    @Log(title = "车辆型号", businessType = BusinessType.UPDATE)
//    @PutMapping("/model")
//    public AjaxResult editModel(@RequestBody EModel etModel)
//    {
//        logger.info("修改车辆型号：【{}】", JSON.toJSONString(etModel));
//        return toAjax(modelService.updateEModel(etModel));
//    }
//
//    /**
//     * 删除车辆型号
//     */
//    @Log(title = "车辆型号", businessType = BusinessType.DELETE)
//    @DeleteMapping("/model/{modelIds}")
//    public AjaxResult removeModel(@PathVariable Long[] modelIds)
//    {
//        logger.info("删除车辆型号：【{}】", JSON.toJSONString(modelIds));
//        for (Long modelId : modelIds){
//            EModel model = new EModel();
//            model.setDelFlag("1");
//            model.setModelId(modelId);
//            int i = modelService.updateEModel(model);
//            if(i == 0){
//                return AjaxResult.warn("【车辆型号】删除失败");
//            }
//        }
//        return toAjax(1);
//    }

    /**
     * 查询文章列表
     */
    @GetMapping("/article/list")
    public TableDataInfo articleList(EtArticle etArticle)
    {
        startPage();
        List<EtArticle> list = articleService.selectAsArticleListByApp(etArticle);
        return getDataTable(list);
    }

    /**
     * 获取文章详细信息
     */
    @GetMapping(value = "/article/{articleId}")
    public AjaxResult getArticleInfo(@PathVariable("articleId") Long articleId)
    {
        return success(articleService.selectAsArticleByArticleId(articleId));
    }

    /**
     * 根据查询文章分类列表
     */
    @GetMapping("/classify/list")
    public AjaxResult classifyList(AsArticleClassify asArticleClassify)
    {
        logger.info("查询分类列表：【asArticleClassify="+asArticleClassify+"】");
        List<AsArticleClassify> asArticleClassifies = articleClassifyService.selectClassifyList(asArticleClassify);
        return success(asArticleClassifies);
    }

    /**
     * 扫码领取钥匙
     * 1. 绑定shareId
     * 2. 改变状态
     */
    @PostMapping("/claimKey")
    public AjaxResult claimKey(Long keyId)
    {
        logger.info("扫码领取钥匙:keyId=【{}】", keyId);
        EShareKey eShareKey = shareKeyService.selectEShareKeyByKeyId(keyId);
        if(!ServiceConstants.KEY_STATUS_NEW.equals(eShareKey.getStatus())){
            return AjaxResult.error("【扫码领取钥匙】失败,非待领取状态");
        }
        EShareKey bandKey = geteShareKey(keyId);
        return success(shareKeyService.updateEShareKey(bandKey));
    }

    private @NotNull EShareKey geteShareKey(Long keyId) {
        EUserVO userVO = userService.selectUserById(getUserId());
        EShareKey bandKey = new EShareKey();
        bandKey.setKeyId(keyId);
        bandKey.setShareId(getUserId());
        bandKey.setShareUserName(userVO.getUserName());
        bandKey.setSharePhone(userVO.getPhonenumber());
        bandKey.setStatus(ServiceConstants.KEY_STATUS_RECEIVED);
        return bandKey;
    }

}
