package com.ruoyi.web.controller.system;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.changeBalance.EChangeBalance;
import com.ruoyi.system.service.IEChangeBalanceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 余额变动Controller
 *
 * @author qzz
 * @date 2024-09-28
 */
@RestController
@RequestMapping("/system/changeBalance")
public class EChangeBalanceController extends BaseController
{
    @Autowired
    private IEChangeBalanceService rlChangeBalanceService;

    /**
     * 查询余额变动列表
     */
    @PreAuthorize("@ss.hasPermi('system:changeBalance:list')")
    @GetMapping("/list")
    public TableDataInfo list(EChangeBalance rlChangeBalance)
    {
        startPage();
        List<EChangeBalance> list = rlChangeBalanceService.selectRlChangeBalanceList(rlChangeBalance);
        return getDataTable(list);
    }

    /**
     * 导出余额变动列表
     */
    @PreAuthorize("@ss.hasPermi('system:changeBalance:export')")
    @Log(title = "余额变动", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EChangeBalance rlChangeBalance)
    {
        List<EChangeBalance> list = rlChangeBalanceService.selectRlChangeBalanceList(rlChangeBalance);
        ExcelUtil<EChangeBalance> util = new ExcelUtil<EChangeBalance>(EChangeBalance.class);
        util.exportExcel(response, list, "余额变动数据");
    }

    /**
     * 获取余额变动详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:changeBalance:query')")
    @GetMapping(value = "/{changeId}")
    public AjaxResult getInfo(@PathVariable("changeId") Long changeId)
    {
        return success(rlChangeBalanceService.selectRlChangeBalanceByChangeId(changeId));
    }

    /**
     * 新增余额变动
     */
    @PreAuthorize("@ss.hasPermi('system:changeBalance:add')")
    @Log(title = "余额变动", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EChangeBalance rlChangeBalance)
    {
        return toAjax(rlChangeBalanceService.insertRlChangeBalance(rlChangeBalance));
    }

    /**
     * 修改余额变动
     */
    @PreAuthorize("@ss.hasPermi('system:changeBalance:edit')")
    @Log(title = "余额变动", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EChangeBalance rlChangeBalance)
    {
        return toAjax(rlChangeBalanceService.updateRlChangeBalance(rlChangeBalance));
    }

    /**
     * 删除余额变动
     */
    @PreAuthorize("@ss.hasPermi('system:changeBalance:remove')")
    @Log(title = "余额变动", businessType = BusinessType.DELETE)
	@DeleteMapping("/{changeIds}")
    public AjaxResult remove(@PathVariable Long[] changeIds)
    {
        return toAjax(rlChangeBalanceService.deleteRlChangeBalanceByChangeIds(changeIds));
    }
}
