package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.clean.EClean;
import com.ruoyi.system.domain.clean.ECleanVO;
import com.ruoyi.system.domain.clean.ECleanQuery;
import com.ruoyi.system.service.IECleanService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 保洁记录Controller
 *
 * @author qzz
 * @date 2024-11-19
 */
@RestController
@RequestMapping("/system/clean")
public class ECleanController extends BaseController
{
    @Autowired
    private IECleanService eCleanService;

    /**
     * 查询保洁记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:clean:list')")
    @GetMapping("/list")
    public TableDataInfo list(ECleanQuery query)
    {
        startPage();
        startOrderBy();
        List<ECleanVO> list = eCleanService.selectECleanList(query);
        return getDataTable(list);
    }

    /**
     * 导出保洁记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:clean:export')")
    @Log(title = "保洁记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ECleanQuery query)
    {
        List<ECleanVO> list = eCleanService.selectECleanList(query);
        ExcelUtil<ECleanVO> util = new ExcelUtil<ECleanVO>(ECleanVO.class);
        util.exportExcel(response, list, "保洁记录数据");
    }

    /**
     * 获取保洁记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:clean:query')")
    @GetMapping(value = "/{cleanId}")
    public AjaxResult getInfo(@PathVariable("cleanId") Long cleanId)
    {
        return success(eCleanService.selectECleanByCleanId(cleanId));
    }

    /**
     * 新增保洁记录
     */
    @PreAuthorize("@ss.hasPermi('system:clean:add')")
    @Log(title = "保洁记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EClean eClean)
    {
        return toAjax(eCleanService.insertEClean(eClean));
    }

    /**
     * 修改保洁记录
     */
    @PreAuthorize("@ss.hasPermi('system:clean:edit')")
    @Log(title = "保洁记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EClean eClean)
    {
        return toAjax(eCleanService.updateEClean(eClean));
    }

    /**
     * 删除保洁记录
     */
    @PreAuthorize("@ss.hasPermi('system:clean:remove')")
    @Log(title = "保洁记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{cleanIds}")
    public AjaxResult remove(@PathVariable Long[] cleanIds)
    {
        return toAjax(eCleanService.deleteECleanByCleanIds(cleanIds));
    }
}
