package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.rule.EFeeRule;
import com.ruoyi.system.domain.rule.EFeeRuleVO;
import com.ruoyi.system.domain.rule.EFeeRuleQuery;
import com.ruoyi.system.service.IEFeeRuleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 收费模板Controller
 *
 * @author qzz
 * @date 2024-11-20
 */
@RestController
@RequestMapping("/system/rule")
public class EFeeRuleController extends BaseController
{
    @Autowired
    private IEFeeRuleService eFeeRuleService;

    /**
     * 查询收费模板列表
     */
    @PreAuthorize("@ss.hasPermi('system:rule:list')")
    @GetMapping("/list")
    public TableDataInfo list(EFeeRuleQuery query)
    {
        startPage();
        startOrderBy();
        List<EFeeRuleVO> list = eFeeRuleService.selectEFeeRuleList(query);
        return getDataTable(list);
    }

    /**
     * 导出收费模板列表
     */
    @PreAuthorize("@ss.hasPermi('system:rule:export')")
    @Log(title = "收费模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EFeeRuleQuery query)
    {
        List<EFeeRuleVO> list = eFeeRuleService.selectEFeeRuleList(query);
        ExcelUtil<EFeeRuleVO> util = new ExcelUtil<EFeeRuleVO>(EFeeRuleVO.class);
        util.exportExcel(response, list, "收费模板数据");
    }

    /**
     * 获取收费模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:rule:query')")
    @GetMapping(value = "/{ruleId}")
    public AjaxResult getInfo(@PathVariable("ruleId") Long ruleId)
    {
        return success(eFeeRuleService.selectEFeeRuleByRuleId(ruleId));
    }

    /**
     * 新增收费模板
     */
    @PreAuthorize("@ss.hasPermi('system:rule:add')")
    @Log(title = "收费模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EFeeRule eFeeRule)
    {
        return toAjax(eFeeRuleService.insertEFeeRule(eFeeRule));
    }

    /**
     * 修改收费模板
     */
    @PreAuthorize("@ss.hasPermi('system:rule:edit')")
    @Log(title = "收费模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EFeeRule eFeeRule)
    {
        return toAjax(eFeeRuleService.updateEFeeRule(eFeeRule));
    }

    /**
     * 删除收费模板
     */
    @PreAuthorize("@ss.hasPermi('system:rule:remove')")
    @Log(title = "收费模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ruleIds}")
    public AjaxResult remove(@PathVariable Long[] ruleIds)
    {
        return toAjax(eFeeRuleService.deleteEFeeRuleByRuleIds(ruleIds));
    }
}
