package com.ruoyi.web.controller.system;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.ELocationLog;
import com.ruoyi.system.service.IELocationLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 定位日志Controller
 *
 * @author ruoyi
 * @date 2024-09-12
 */
@RestController
@RequestMapping("/system/locationLog")
public class ELocationLogController extends BaseController
{
    @Autowired
    private IELocationLogService etLocationLogService;

    /**
     * 查询定位日志列表
     */
    @PreAuthorize("@ss.hasPermi('system:locationLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(ELocationLog rlLocationLog)
    {
        startPage();
        List<ELocationLog> list = etLocationLogService.selectEtLocationLogList(rlLocationLog);
        etLocationLogService.analytic(list);
        return getDataTable(list);
    }

    /**
     * 导出定位日志列表
     */
    @PreAuthorize("@ss.hasPermi('system:locationLog:export')")
    @Log(title = "定位日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ELocationLog rlLocationLog)
    {
        List<ELocationLog> list = etLocationLogService.selectEtLocationLogList(rlLocationLog);
        ExcelUtil<ELocationLog> util = new ExcelUtil<ELocationLog>(ELocationLog.class);
        util.exportExcel(response, list, "定位日志数据");
    }

    /**
     * 获取定位日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:locationLog:query')")
    @GetMapping(value = "/{locationId}")
    public AjaxResult getInfo(@PathVariable("locationId") Long locationId)
    {
        return success(etLocationLogService.selectEtLocationLogByLocationId(locationId));
    }

    /**
     * 新增定位日志
     */
    @PreAuthorize("@ss.hasPermi('system:locationLog:add')")
    @Log(title = "定位日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ELocationLog rlLocationLog)
    {
        return toAjax(etLocationLogService.insertEtLocationLog(rlLocationLog));
    }

    /**
     * 修改定位日志
     */
    @PreAuthorize("@ss.hasPermi('system:locationLog:edit')")
    @Log(title = "定位日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ELocationLog rlLocationLog)
    {
        return toAjax(etLocationLogService.updateEtLocationLog(rlLocationLog));
    }

    /**
     * 删除定位日志
     */
    @PreAuthorize("@ss.hasPermi('system:locationLog:remove')")
    @Log(title = "定位日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{locationIds}")
    public AjaxResult remove(@PathVariable Long[] locationIds)
    {
        return toAjax(etLocationLogService.deleteEtLocationLogByLocationIds(locationIds));
    }
}
