package com.ruoyi.web.controller.system;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.area.EOperatingArea;
import com.ruoyi.system.service.IEOperatingAreaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 运营区Controller
 *
 * @author qzz
 * @date 2024-09-18
 */
@RestController
@RequestMapping("/system/area")
public class EOperatingAreaController extends BaseController
{
    @Autowired
    private IEOperatingAreaService rlOperatingAreaService;

    /**
     * 查询运营区列表
     */
    @PreAuthorize("@ss.hasPermi('system:area:list')")
    @GetMapping("/list")
    public TableDataInfo list(EOperatingArea rlOperatingArea)
    {
        startPage();
        List<EOperatingArea> list = rlOperatingAreaService.selectRlOperatingAreaList(rlOperatingArea);
        return getDataTable(list);
    }

    /**
     * 导出运营区列表
     */
    @PreAuthorize("@ss.hasPermi('system:area:export')")
    @Log(title = "运营区", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EOperatingArea rlOperatingArea)
    {
        List<EOperatingArea> list = rlOperatingAreaService.selectRlOperatingAreaList(rlOperatingArea);
        ExcelUtil<EOperatingArea> util = new ExcelUtil<EOperatingArea>(EOperatingArea.class);
        util.exportExcel(response, list, "运营区数据");
    }

    /**
     * 获取运营区详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:area:query')")
    @GetMapping(value = "/{areaId}")
    public AjaxResult getInfo(@PathVariable("areaId") Long areaId)
    {
        return success(rlOperatingAreaService.selectRlOperatingAreaByAreaId(areaId));
    }

    /**
     * 新增运营区
     */
    @PreAuthorize("@ss.hasPermi('system:area:add')")
    @Log(title = "运营区", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EOperatingArea rlOperatingArea)
    {
        return toAjax(rlOperatingAreaService.insertRlOperatingArea(rlOperatingArea));
    }

    /**
     * 修改运营区
     */
    @PreAuthorize("@ss.hasPermi('system:area:edit')")
    @Log(title = "运营区", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EOperatingArea rlOperatingArea)
    {
        return toAjax(rlOperatingAreaService.updateRlOperatingArea(rlOperatingArea));
    }

    /**
     * 删除运营区
     */
    @PreAuthorize("@ss.hasPermi('system:area:remove')")
    @Log(title = "运营区", businessType = BusinessType.DELETE)
	@DeleteMapping("/{areaIds}")
    public AjaxResult remove(@PathVariable Long[] areaIds)
    {
        return toAjax(rlOperatingAreaService.deleteRlOperatingAreaByAreaIds(areaIds));
    }
}
