package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.room.ERoom;
import com.ruoyi.system.domain.room.ERoomVO;
import com.ruoyi.system.domain.room.ERoomQuery;
import com.ruoyi.system.service.IERoomService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 房间Controller
 *
 * @author qzz
 * @date 2024-11-20
 */
@RestController
@RequestMapping("/system/room")
public class ERoomController extends BaseController
{
    @Autowired
    private IERoomService eRoomService;

    /**
     * 查询房间列表
     */
    @PreAuthorize("@ss.hasPermi('system:room:list')")
    @GetMapping("/list")
    public TableDataInfo list(ERoomQuery query)
    {
        startPage();
        startOrderBy();
        List<ERoomVO> list = eRoomService.selectERoomList(query);
        return getDataTable(list);
    }

    /**
     * 导出房间列表
     */
    @PreAuthorize("@ss.hasPermi('system:room:export')")
    @Log(title = "房间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ERoomQuery query)
    {
        List<ERoomVO> list = eRoomService.selectERoomList(query);
        ExcelUtil<ERoomVO> util = new ExcelUtil<ERoomVO>(ERoomVO.class);
        util.exportExcel(response, list, "房间数据");
    }

    /**
     * 获取房间详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:room:query')")
    @GetMapping(value = "/{roomId}")
    public AjaxResult getInfo(@PathVariable("roomId") Long roomId)
    {
        return success(eRoomService.selectERoomByRoomId(roomId));
    }

    /**
     * 新增房间
     */
    @PreAuthorize("@ss.hasPermi('system:room:add')")
    @Log(title = "房间", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ERoom eRoom)
    {
        return toAjax(eRoomService.insertERoom(eRoom));
    }

    /**
     * 修改房间
     */
    @PreAuthorize("@ss.hasPermi('system:room:edit')")
    @Log(title = "房间", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ERoom eRoom)
    {
        return toAjax(eRoomService.updateERoom(eRoom));
    }

    /**
     * 删除房间
     */
    @PreAuthorize("@ss.hasPermi('system:room:remove')")
    @Log(title = "房间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{roomIds}")
    public AjaxResult remove(@PathVariable Long[] roomIds)
    {
        return toAjax(eRoomService.deleteERoomByRoomIds(roomIds));
    }
}
