package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.EShareKey;
import com.ruoyi.system.service.IEShareKeyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 共享钥匙Controller
 *
 * @author 邱贞招
 * @date 2024-07-31
 */
@RestController
@RequestMapping("/system/key")
public class EShareKeyController extends BaseController
{
    @Autowired
    private IEShareKeyService eShareKeyService;

    /**
     * 查询共享钥匙列表
     */
    @PreAuthorize("@ss.hasPermi('system:key:list')")
    @GetMapping("/list")
    public TableDataInfo list(EShareKey eShareKey)
    {
        startPage();
        List<EShareKey> list = eShareKeyService.selectEShareKeyList(eShareKey);
        return getDataTable(list);
    }

    /**
     * 导出共享钥匙列表
     */
    @PreAuthorize("@ss.hasPermi('system:key:export')")
    @Log(title = "共享钥匙", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EShareKey eShareKey)
    {
        List<EShareKey> list = eShareKeyService.selectEShareKeyList(eShareKey);
        ExcelUtil<EShareKey> util = new ExcelUtil<EShareKey>(EShareKey.class);
        util.exportExcel(response, list, "共享钥匙数据");
    }

    /**
     * 获取共享钥匙详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:key:query')")
    @GetMapping(value = "/{keyId}")
    public AjaxResult getInfo(@PathVariable("keyId") Long keyId)
    {
        return success(eShareKeyService.selectEShareKeyByKeyId(keyId));
    }

    /**
     * 新增共享钥匙
     */
    @PreAuthorize("@ss.hasPermi('system:key:add')")
    @Log(title = "共享钥匙", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EShareKey eShareKey)
    {
        return toAjax(eShareKeyService.insertEShareKey(eShareKey));
    }

    /**
     * 修改共享钥匙
     */
    @PreAuthorize("@ss.hasPermi('system:key:edit')")
    @Log(title = "共享钥匙", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EShareKey eShareKey)
    {
        return toAjax(eShareKeyService.updateEShareKey(eShareKey));
    }

    /**
     * 删除共享钥匙
     */
    @PreAuthorize("@ss.hasPermi('system:key:remove')")
    @Log(title = "共享钥匙", businessType = BusinessType.DELETE)
	@DeleteMapping("/{keyIds}")
    public AjaxResult remove(@PathVariable Long[] keyIds)
    {
        return toAjax(eShareKeyService.deleteEShareKeyByKeyIds(keyIds));
    }
}
