package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.store.EStore;
import com.ruoyi.system.domain.store.EStoreVO;
import com.ruoyi.system.domain.store.EStoreQuery;
import com.ruoyi.system.service.IEStoreService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 店铺Controller
 *
 * @author qzz
 * @date 2024-11-20
 */
@RestController
@RequestMapping("/system/store")
public class EStoreController extends BaseController
{
    @Autowired
    private IEStoreService eStoreService;

    /**
     * 查询店铺列表
     */
    @PreAuthorize("@ss.hasPermi('system:store:list')")
    @GetMapping("/list")
    public TableDataInfo list(EStoreQuery query)
    {
        startPage();
        startOrderBy();
        List<EStoreVO> list = eStoreService.selectEStoreList(query);
        return getDataTable(list);
    }

    /**
     * 导出店铺列表
     */
    @PreAuthorize("@ss.hasPermi('system:store:export')")
    @Log(title = "店铺", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EStoreQuery query)
    {
        List<EStoreVO> list = eStoreService.selectEStoreList(query);
        ExcelUtil<EStoreVO> util = new ExcelUtil<EStoreVO>(EStoreVO.class);
        util.exportExcel(response, list, "店铺数据");
    }

    /**
     * 获取店铺详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:store:query')")
    @GetMapping(value = "/{storeId}")
    public AjaxResult getInfo(@PathVariable("storeId") Long storeId)
    {
        return success(eStoreService.selectEStoreByStoreId(storeId));
    }

    /**
     * 新增店铺
     */
    @PreAuthorize("@ss.hasPermi('system:store:add')")
    @Log(title = "店铺", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EStore eStore)
    {
        return toAjax(eStoreService.insertEStore(eStore));
    }

    /**
     * 修改店铺
     */
    @PreAuthorize("@ss.hasPermi('system:store:edit')")
    @Log(title = "店铺", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EStore eStore)
    {
        return toAjax(eStoreService.updateEStore(eStore));
    }

    /**
     * 删除店铺
     */
    @PreAuthorize("@ss.hasPermi('system:store:remove')")
    @Log(title = "店铺", businessType = BusinessType.DELETE)
	@DeleteMapping("/{storeIds}")
    public AjaxResult remove(@PathVariable Long[] storeIds)
    {
        return toAjax(eStoreService.deleteEStoreByStoreIds(storeIds));
    }
}
