package com.ruoyi.system.device.service.impl;

import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.device.domain.DeviceBO;
import com.ruoyi.system.device.domain.dto.DeviceRegisterDTO;
import com.ruoyi.system.device.service.DeviceConverter;
import com.ruoyi.system.model.domain.EModelVO;
import com.ruoyi.system.model.domain.enums.ModelTag;
import com.ruoyi.system.model.service.IEModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author wjh
 * 2024/7/15
 */
@Service
public class DeviceConverterImpl implements DeviceConverter {

    @Autowired
    private  IEModelService modelService;

    private final String WIFI_MAC = "D8";

    private final String FOUR_G_MAC = "4C";

    @Override
    public DeviceBO toBOByRegister(DeviceRegisterDTO dto) {

        EModelVO model = modelService.selectSmModelByModelId(dto.getModelId());
        ServiceUtil.assertion(model == null, "型号不存在");

        // 添加
        DeviceBO device = new DeviceBO();
        device.setDeviceName("未命名");
        device.setMac(dto.getMac());
        device.setDeviceNo(dto.getSn());
        device.setModelId(dto.getModelId());
        device.setServiceType(model.getServiceType());
        device.setServiceRate(model.getServiceRate());

        // 若为双模版本的型号，则注册4G或WIFI版本MAC
        if (ModelTag.isTwoMac(model.getTags())) {
            if (device.getMac().endsWith(FOUR_G_MAC)) {
                device.setMac2(StringUtils.replaceLast(device.getMac(), FOUR_G_MAC, WIFI_MAC));
            } else {
                // 替换最后两位为4G MAC
                String substring = device.getMac().substring(0, device.getMac().length() - 2);
                device.setMac2(substring + FOUR_G_MAC);
            }
        }

        return device;
    }

}
