package com.ruoyi.system.intention.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.intention.service.IEIntentionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.intention.mapper.EIntentionMapper;
import com.ruoyi.system.intention.domain.EIntention;
import com.ruoyi.system.intention.domain.EIntentionVO;
import com.ruoyi.system.intention.domain.EIntentionQuery;

/**
 * 合作意向Service业务层处理
 *
 * @author qzz
 * @date 2024-11-21
 */
@Service
public class EIntentionServiceImpl implements IEIntentionService
{
    @Autowired
    private EIntentionMapper eIntentionMapper;

    /**
     * 查询合作意向
     *
     * @param intentionId 合作意向主键
     * @return 合作意向
     */
    @Override
    public EIntentionVO selectEIntentionByIntentionId(Long intentionId)
    {
        return eIntentionMapper.selectEIntentionByIntentionId(intentionId);
    }

    /**
     * 查询合作意向列表
     *
     * @param eIntention 合作意向
     * @return 合作意向
     */
    @Override
    public List<EIntentionVO> selectEIntentionList(EIntentionQuery eIntention)
    {
        return eIntentionMapper.selectEIntentionList(eIntention);
    }

    /**
     * 新增合作意向
     *
     * @param eIntention 合作意向
     * @return 结果
     */
    @Override
    public int insertEIntention(EIntention eIntention)
    {
        eIntention.setCreateTime(DateUtils.getNowDate());
        return eIntentionMapper.insertEIntention(eIntention);
    }

    /**
     * 修改合作意向
     *
     * @param eIntention 合作意向
     * @return 结果
     */
    @Override
    public int updateEIntention(EIntention eIntention)
    {
        return eIntentionMapper.updateEIntention(eIntention);
    }

    /**
     * 批量删除合作意向
     *
     * @param intentionIds 需要删除的合作意向主键
     * @return 结果
     */
    @Override
    public int deleteEIntentionByIntentionIds(Long[] intentionIds)
    {
        return eIntentionMapper.deleteEIntentionByIntentionIds(intentionIds);
    }

    /**
     * 删除合作意向信息
     *
     * @param intentionId 合作意向主键
     * @return 结果
     */
    @Override
    public int deleteEIntentionByIntentionId(Long intentionId)
    {
        return eIntentionMapper.deleteEIntentionByIntentionId(intentionId);
    }
}
