package com.ruoyi.system.order.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 订单对象 rl_order
 *
 * @author qzz
 * @date 2024-09-19
 */
@Data
public class EOrder extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 订单id
     */
    private Long orderId;

    /**
     * 订单号
     */
    @Excel(name = "订单号")
    private String orderNo;

//    /**
//     * 微信商户系统内部的订单号,32个字符内、可包含字母, 其他说明见商户订单号
//     */
//    @Excel(name = "微信商户系统内部的订单号,32个字符内、可包含字母, 其他说明见商户订单号")
//    private String outTradeNo;

    /**
     * 用户ID
     */
    @Excel(name = "用户ID")
    private Long userId;

    /**
     * 用户名
     */
    @Excel(name = "用户名")
    private String userName;

    /**
     * 真实姓名
     */
    @Excel(name = "真实姓名")
    private String realName;

    /**
     * 手机号
     */
    @Excel(name = "手机号")
    private String phone;

    /**
     * 套餐id
     */
    @Excel(name = "套餐id")
    private Long ruleId;

    /**
     * 大门mac
     */
    @Excel(name = "大门mac")
    private String gateMac;

    /**
     * 大门sn码
     */
    @Excel(name = "大门sn码")
    private String gateSn;

    /**
     * 房间门mac
     */
    @Excel(name = "房间门mac")
    private String roomMac;

    /**
     * 房间门sn码
     */
    @Excel(name = "房间门sn码")
    private String roomSn;

    /**
     * 支付时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "支付时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date payTime;

    /**
     * 支付方式: wx-微信，alipay-支付宝，ye-余额支付
     */
    @Excel(name = "支付方式")
    private String payType;

    /**
     * 支付状态
     */
    @Excel(name = "支付状态")
    private String paid;

    /**
     * 类型
     */
    @Excel(name = "类型")
    private String type;

    /**
     * 订单总金额（元）
     */
    @Excel(name = "订单总金额", readConverterExp = "元")
    private BigDecimal totalFee;

    /**
     * 实际支付金额
     */
    @Excel(name = "实际支付金额")
    private BigDecimal payFee;

    /**
     * 备注
     */
    @Excel(name = "备注")
    private String mark;

    /**
     * 状态
     */
    @Excel(name = "状态")
    private String status;

    /**
     * 预定开始时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "预定开始时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date reserveStartTime;

    /**
     * 预定结束时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "预定结束时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date reserveEndTime;

    /**
     * 换包间原因
     */
    private String changeReason;

    /**
     * 手续费
     */
    @Excel(name = "手续费")
    private BigDecimal handlingCharge;

    /**
     * 服务费
     */
    @Excel(name = "服务费")
    private BigDecimal platformServiceFee;

    /**
     * 运营商分账
     */
    @Excel(name = "运营商分账")
    private BigDecimal operatorDividend;

    /**
     * 支付渠道id
     */
    @Excel(name = "支付渠道id")
    private Long payChannel;

    /**
     * 支付渠道名称
     */
    @Excel(name = "支付渠道名称")
    private String channelName;

    /**
     * 店铺id
     */
    @Excel(name = "店铺id")
    private Long storeId;

    /**
     * 店铺名称
     */
    @Excel(name = "店铺名称")
    private String storeName;

    /**
     * 房间id
     */
    @Excel(name = "房间id")
    private Long roomId;

    /**
     * 房间名称
     */
    @Excel(name = "房间名称")
    private String roomName;

    /**
     * 商户id
     */
    @Excel(name = "商户id")
    private Long merchantId;

    /**
     * 商户名
     */
    @Excel(name = "商户名")
    private String merchantName;

    /**
     * 下单城市
     */
    @Excel(name = "下单城市")
    private Long cityId;

    /**
     * 原订单号  订单类型为续单时需要
     */
    private String originalOrderNo;

    /**----------------------------套餐start----------------------------*/

    @Excel(name = "套餐：1-按小时计费；2-自定义模板")
    @ApiModelProperty("套餐")
    private String mode;

    @Excel(name = "小时")
    @ApiModelProperty("小时")
    private Integer hours;

    @Excel(name = "售价")
    @ApiModelProperty("售价")
    private BigDecimal price;

    @Excel(name = "说明")
    @ApiModelProperty("说明")
    private String explain;

    /**----------------------------套餐end----------------------------*/

    /**
     * 系统自动取消时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "支付时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date autoCancelTime;

    /**
     * 成本
     */
    private BigDecimal cost;

    /**
     * 是否已发送过短信提醒
     */
    @Excel(name = "是否已发送过短信提醒")
    private Boolean isSendMsg;
}
