package com.ruoyi.system.order.domain.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.constant.DictTypeConstants;
import com.ruoyi.system.valid.DictValid;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import java.math.BigDecimal;
import java.util.Date;

@Data
public class EOrderDTO {

    /**----------------------------套餐start----------------------------*/

    /**
     * 套餐id
     */
    @ApiModelProperty("套餐id")
    @NotBlank(message = "套餐id不允许为空")
    private Long ruleId;

    @ApiModelProperty("套餐：1-按小时计费；2-自定义模板")
    @NotBlank(message = "套餐不允许为空")
    @DictValid(type = DictTypeConstants.FEE_RULE_MODE, message = "非法的套餐")
    private String mode;

    @ApiModelProperty("小时")
    @NotBlank(message = "小时不允许为空")
    private Integer hours;

    @ApiModelProperty("售价")
    @NotBlank(message = "售价不允许为空")
    private BigDecimal price;

    /**----------------------------套餐end----------------------------*/

    @ApiModelProperty("预定开始时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @NotBlank(message = "预定开始时间不允许为空")
    private Date reserveStartTime;

    @ApiModelProperty("房间id")
    @NotBlank(message = "房间id不允许为空")
    private Long roomId;

    @ApiModelProperty("支付方式：wx-微信，alipay-支付宝，ye-余额支付")
    @NotBlank(message = "支付方式不允许为空")
    @DictValid(type = DictTypeConstants.PAY_TYPE, message = "非法的支付方式")
    private String payType;

    @ApiModelProperty("订单类型：1-预定单；2-续单;3-余额充值")
    @NotBlank(message = "订单类型不允许为空")
    @DictValid(type = DictTypeConstants.ORDER_TYPE, message = "非法的订单类型")
    private String type;

}
