package com.ruoyi.system.order.mapper;

import com.ruoyi.system.order.domain.EOrder;
import com.ruoyi.system.order.domain.EOrderQuery;
import com.ruoyi.system.order.domain.EOrderVO;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * 订单Mapper接口
 *
 * @author qzz
 * @date 2024-09-19
 */
public interface EOrderMapper
{
    /**
     * 查询订单
     *
     * @param orderId 订单主键
     * @return 订单
     */
    public EOrderVO selectRlOrderByOrderId(Long orderId);

    /**
     * 查询订单
     *
     * @param orderNo 订单号
     * @return 订单
     */
    public EOrderVO selectRlOrderByOrderNo(String orderNo);

    /**
     * 查询订单列表
     *
     * @param rlOrder 订单
     * @return 订单集合
     */
    public List<EOrderVO> selectRlOrderList(EOrderQuery rlOrder);

    /**
     * 查询所有订单列表
     *
     * @param rlOrder 订单
     * @return 订单集合
     */
    public List<EOrderVO> selectAllRlOrderList(EOrderQuery rlOrder);

    /**
     * 新增订单
     *
     * @param rlOrder 订单
     * @return 结果
     */
    public int insertRlOrder(EOrder rlOrder);

    /**
     * 修改订单
     *
     * @param rlOrder 订单
     * @return 结果
     */
    public int updateRlOrder(EOrder rlOrder);

    /**
     * 修改订单
     *
     * @param rlOrder 订单
     * @return 结果
     */
    public int updateRlOrderByOrderNo(EOrder rlOrder);

    /**
     * 删除订单
     *
     * @param orderId 订单主键
     * @return 结果
     */
    public int deleteRlOrderByOrderId(Long orderId);

    /**
     * 批量删除订单
     *
     * @param orderIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRlOrderByOrderIds(Long[] orderIds);


    /**
     * 第三方订单号
     *
     * @param outTradeNo 订单号
     * @return 订单
     */
    EOrderVO selectRlOrderByOutTradeNo(String outTradeNo);

    /**
     * 根据sn查询正在进行中的订单
     */
    List<EOrderVO> getInProgressOrder(String sn);

    /**
     * 订单金额
     */
    BigDecimal getOrderFee(@Param("startDateStr") String startDateStr , @Param("endDateStr") String endDateStr ,@Param("merchantId") Long merchantId);

    /**
     * 订单数量
     */
    Integer getOrderNum(@Param("startDateStr") String startDateStr , @Param("endDateStr") String endDateStr ,@Param("merchantId") Long merchantId);

//    /**
//     * 扫码绑定车辆
//     */
//    int bandDevice(String orderNo, String sn);
}
