package com.ruoyi.system.order.service;

import com.ruoyi.common.utils.wx.vo.PrepayResponseVO;
import com.ruoyi.system.order.domain.EOrder;
import com.ruoyi.system.order.domain.EOrderQuery;
import com.ruoyi.system.order.domain.EOrderVO;
import com.ruoyi.system.domain.refund.ERefund;
import com.ruoyi.system.domain.vo.IndexAdminVo;
import com.ruoyi.system.order.domain.dto.EOrderDTO;

import java.math.BigDecimal;
import java.util.List;

/**
 * 订单Service接口
 *
 * @author qzz
 * @date 2024-09-19
 */
public interface IEOrderService
{
    /**
     * 查询订单
     *
     * @param orderId 订单主键
     * @return 订单
     */
    public EOrderVO selectRlOrderByOrderId(Long orderId);

    /**
     * 查询订单
     *
     * @param orderNo 订单主键
     * @return 订单
     */
    public EOrderVO selectRlOrderByOrderNo(String orderNo);

    /**
     * 查询订单
     *
     * @param outTradeNo 第三方订单号
     * @return 订单
     */
    public EOrderVO selectRlOrderByOutTradeNo(String outTradeNo);

    /**
     * 查询订单详情，详细信息
     *
     * @param orderNo 订单主键
     * @return 订单
     */
    public EOrderVO getOrderInfoByOrderNo(String orderNo);

    /**
     * 查询订单列表
     *
     * @param rlOrder 订单
     * @return 订单集合
     */
    public List<EOrderVO> selectRlOrderList(EOrderQuery rlOrder);

    /**
     * 查询订单列表
     *
     * @param rlOrder 订单
     * @return 订单集合
     */
    public List<EOrderVO> selectRlOrderListNoIsolate(EOrderQuery rlOrder);

    /**
     * 查询所有订单列表
     *
     * @param rlOrder 订单
     * @return 订单
     */
    public List<EOrderVO> selectAllRlOrderList(EOrderQuery rlOrder);

    /**
     * 新增订单
     *
     * @param rlOrder 订单
     * @return 结果
     */
    public int insertRlOrder(EOrderQuery rlOrder);

    /**
     * 修改订单
     *
     * @param rlOrder 订单
     * @return 结果
     */
    public int updateRlOrder(EOrder rlOrder);

    /**
     * 修改订单
     *
     * @param rlOrder 订单
     * @return 结果
     */
    public int updateRlOrderByOrderNo(EOrder rlOrder);

    /**
     * 批量删除订单
     *
     * @param orderIds 需要删除的订单主键集合
     * @return 结果
     */
    public int deleteRlOrderByOrderIds(Long[] orderIds);

    /**
     * 删除订单信息
     *
     * @param orderId 订单主键
     * @return 结果
     */
    public int deleteRlOrderByOrderId(Long orderId);

    /**
     * 下单
     */
    PrepayResponseVO createOrder(EOrderDTO order);

    /**
     * 确认支付
     */
    PrepayResponseVO confirmPay(String orderNo);

    /**
     * 扫码绑定车辆
     */
    int bandDevice(String orderNo, String sn);

    /**
     * 用户扫码绑定车辆
     */
    int userBandDevice(Long userId, String sn);

    /**
     * 续单
     */
    PrepayResponseVO relet(EOrderQuery order);

    /**
     * 订单取消
     */
    Boolean orderCancel(String orderNo);

    /**
     * 车损扣款
     */
    Boolean deductMoney(BigDecimal money, String orderNo);

//    /**
//     * 押金退款
//     */
//    Boolean depositRefund(String orderNo);

//    /**
//     * 商家还车
//     */
//    Boolean merchantReturn(String orderNo);

    /**
     * 订单退款
     */
    int refund(EOrderQuery order);

    /**
     * 创建退款
     *
     */
    public ERefund createRefund(String reason, Long userId, String orderNo,
                                BigDecimal refundAmount,
                                BigDecimal dispatchFee,
                                BigDecimal deliveryFee,
                                BigDecimal leaseFee, String outRefundNo, String type);




//    /**
//     * 根据订单号查询可还车的店铺
//     */
//    List<StoreVo> getReturnStoreList(String orderNo,String lon,String lat);

    /**
     * 根据sn查询正在进行中的订单
     */
    EOrderVO getInProgressOrder(String sn);


    void validate(EOrderQuery orderQuery);

    /**
     * app首页统计
     */
    IndexAdminVo indexStatistics(String startTime, String endTime, Long userId);
}
