package com.ruoyi.system.order.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.ruoyi.common.core.domain.entity.EUserVO;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.system.domain.room.ERoomVO;
import com.ruoyi.system.domain.rule.EFeeRuleVO;
import com.ruoyi.system.domain.store.EStoreVO;
import com.ruoyi.system.order.domain.EOrderBO;
import com.ruoyi.system.order.domain.dto.EOrderDTO;
import com.ruoyi.system.order.service.IEOrderConverter;
import com.ruoyi.system.service.IEFeeRuleService;
import com.ruoyi.system.service.IERoomService;
import com.ruoyi.system.service.IEStoreService;
import com.ruoyi.system.service.IEUserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
public class EOrderConverterImpl implements IEOrderConverter {


    @Resource
    private IERoomService roomService;

    @Resource
    private IEFeeRuleService feeRuleService;

    @Resource
    private IEUserService userService;

    @Resource
    private IEStoreService storeService;

    // 订单dto转bo
    @Override
    public EOrderBO toOrderBO(EOrderDTO order) {

        // 房间
        ERoomVO eRoomVO = roomService.selectERoomByRoomId(order.getRoomId());
        ServiceUtil.assertion(eRoomVO == null, "房间不存在");

        // 店铺
        EStoreVO eStoreVO = storeService.selectEStoreByStoreId(eRoomVO.getStoreId());
        ServiceUtil.assertion(eStoreVO == null, "店铺不存在");

        // 商户
        EUserVO merchantVO =  userService.selectUserById(eStoreVO.getManagerId());
        ServiceUtil.assertion(merchantVO == null, "商户不存在");

        ServiceUtil.assertion(merchantVO.getServiceFeeProportion() == null, "商户【"+merchantVO.getUserName()+"】的平台服务费未配置");
        ServiceUtil.assertion(merchantVO.getPayChannel() == null, "商户【"+merchantVO.getUserName()+"】的支付渠道未配置");

        // 套餐
        EFeeRuleVO eFeeRuleVO = feeRuleService.selectEFeeRuleByRuleId(order.getRuleId());
        ServiceUtil.assertion(eFeeRuleVO == null, "套餐不存在");

        // 用户
        EUserVO eUserVO = userService.selectUserById(SecurityUtils.getUserId());
        ServiceUtil.assertion(eUserVO == null, "用户不存在");
        ServiceUtil.assertion(eUserVO.getWxopenid() == null, "用户微信openId为空");

        EOrderBO orderBO = new EOrderBO();
        orderBO.setParams(order);
        orderBO.setRoom(eRoomVO);
        orderBO.setFeeRule(eFeeRuleVO);
        orderBO.setMerchant(merchantVO);
        orderBO.setStore(eStoreVO);
        return orderBO;
    }
}
