package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.EShareKey;

/**
 * 共享钥匙Service接口
 *
 * @author 邱贞招
 * @date 2024-07-31
 */
public interface IEShareKeyService
{
    /**
     * 查询共享钥匙
     *
     * @param keyId 共享钥匙主键
     * @return 共享钥匙
     */
    public EShareKey selectEShareKeyByKeyId(Long keyId);

    /**
     * 查询共享钥匙列表
     *
     * @param eShareKey 共享钥匙
     * @return 共享钥匙集合
     */
    public List<EShareKey> selectEShareKeyList(EShareKey eShareKey);

    /**
     * 根据归属用户id查询共享钥匙列表(正常)
     *
     * @param ownerId 归属用户id
     * @return 共享钥匙集合
     */
    public List<EShareKey> selectEShareKeyListByOwnerId(Long ownerId);

    /**
     * 根据归属用户id查询共享钥匙列表(已失效)
     *
     * @param ownerId 归属用户id
     * @return 共享钥匙集合
     */
    public List<EShareKey> selectExpiredEShareKeyListByOwnerId(Long ownerId);

    /**
     * 根据被分享用户id查询共享钥匙列表
     *
     * @param shareUserId 被分享用户id
     * @return 共享钥匙集合
     */
    public List<EShareKey> selectEShareKeyListByShareUserId(Long shareUserId);

    /**
     * 新增共享钥匙
     *
     * @param eShareKey 共享钥匙
     * @return 结果
     */
    public int insertEShareKey(EShareKey eShareKey);

    /**
     * 修改共享钥匙
     *
     * @param eShareKey 共享钥匙
     * @return 结果
     */
    public int updateEShareKey(EShareKey eShareKey);

    /**
     * 批量删除共享钥匙
     *
     * @param keyIds 需要删除的共享钥匙主键集合
     * @return 结果
     */
    public int deleteEShareKeyByKeyIds(Long[] keyIds);

    /**
     * 删除共享钥匙信息
     *
     * @param keyId 共享钥匙主键
     * @return 结果
     */
    public int deleteEShareKeyByKeyId(Long keyId);
}
