package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.store.EStore;
import com.ruoyi.system.domain.store.EStoreVO;
import com.ruoyi.system.domain.store.EStoreQuery;

/**
 * 店铺Service接口
 *
 * @author qzz
 * @date 2024-11-20
 */
public interface IEStoreService
{
    /**
     * 查询店铺
     *
     * @param storeId 店铺主键
     * @return 店铺
     */
    public EStoreVO selectEStoreByStoreId(Long storeId);

    /**
     * 查询店铺列表
     *
     * @param eStore 店铺
     * @return 店铺集合
     */
    public List<EStoreVO> selectEStoreList(EStoreQuery eStore);

    /**
     * 新增店铺
     *
     * @param eStore 店铺
     * @return 结果
     */
    public int insertEStore(EStore eStore);

    /**
     * 修改店铺
     *
     * @param eStore 店铺
     * @return 结果
     */
    public int updateEStore(EStore eStore);

    /**
     * 批量删除店铺
     *
     * @param storeIds 需要删除的店铺主键集合
     * @return 结果
     */
    public int deleteEStoreByStoreIds(Long[] storeIds);

    /**
     * 删除店铺信息
     *
     * @param storeId 店铺主键
     * @return 结果
     */
    public int deleteEStoreByStoreId(Long storeId);


    /**
     * 根据定位获取附近店铺列表
     */
    List<EStoreVO> getStoreListByLocation(EStoreQuery query);

    /**
     * 开大门
     */
    boolean openGate(Long storeId);

    /**
     * 关大门
     */
    boolean closeGate(Long storeId);
}
