package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.entity.EUser;
import com.ruoyi.common.core.domain.entity.EUserVO;
import com.ruoyi.system.domain.EUserQuery;
import com.ruoyi.system.domain.changeBalance.EChangeBalance;
import com.ruoyi.system.domain.changeBalance.EChangeBalanceQuery;
import com.ruoyi.system.domain.query.AuthenticationQuery;
import com.ruoyi.system.domain.withdraw.EWithdrawQuery;

import java.math.BigDecimal;
import java.util.List;

/**
 * 用户 业务层
 *
 * @author ruoyi
 */
public interface IEUserService
{
    /**
     * 根据条件分页查询用户列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<EUserVO> selectUserList(EUserQuery user);

    /**
     * 获取app用户列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<EUserVO> selectAppUserList(EUserQuery user);


    /**
     * 根据条件分页查询已分配用户角色列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<EUser> selectAllocatedList(EUser user);

    /**
     * 根据条件分页查询未分配用户角色列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<EUser> selectUnallocatedList(EUser user);

    /**
     * 通过用户名查询用户
     *
     * @param userName 用户名
     * @return 用户对象信息
     */
    public EUserVO selectUserByUserName(String userName);

    /**
     * 通过手机号查询用户
     *
     * @param phone 手机号
     * @return 用户对象信息
     */
    public EUserVO selectUserByPhone(String phone);

    /**
     * 通过用户ID查询用户（带角色信息等）
     *
     * @param userId 用户ID
     * @return 用户对象信息
     */
    public EUserVO selectUserById(Long userId);

    /**
     * 通过用户ID查询账户
     *
     * @param EUserId 用户ID
     * @return 用户对象信息
     */
    public EUserVO myAccountInfoByUserId(Long EUserId);



//    /**
//     * 校验用户名称是否唯一
//     *
//     * @param user 用户信息
//     * @return 结果
//     */
//    public boolean checkUserNameUnique(EUser user);
//
//    /**
//     * 校验手机号码是否唯一
//     *
//     * @param user 用户信息
//     * @return 结果
//     */
//    public boolean checkPhoneUnique(EUser user);
//
//    /**
//     * 校验email是否唯一
//     *
//     * @param user 用户信息
//     * @return 结果
//     */
//    public boolean checkEmailUnique(EUser user);
//
    /**
     * 新增用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int insertUser(EUser user);
//
//    /**
//     * 注册用户信息
//     *
//     * @param user 用户信息
//     * @return 结果
//     */
//    public boolean registerUser(EUser user);

    /**
     * 修改用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUser(EUser user);

    /**
     * 修改用户状态
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUserStatus(EUser user);

    /**
     * 修改用户基本信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUserProfile(EUser user);
//
//    /**
//     * 修改用户头像
//     *
//     * @param userName 用户名
//     * @param avatar 头像地址
//     * @return 结果
//     */
//    public boolean updateUserAvatar(String userName, String avatar);
//
//    /**
//     * 重置用户密码
//     *
//     * @param user 用户信息
//     * @return 结果
//     */
//    public int resetPwd(EUser user);
//
//    /**
//     * 重置用户密码
//     *
//     * @param userName 用户名
//     * @param password 密码
//     * @return 结果
//     */
//    public int resetUserPwd(String userName, String password);
//
//    /**
//     * 通过用户ID删除用户
//     *
//     * @param userId 用户ID
//     * @return 结果
//     */
//    public int deleteUserById(Long userId);
//
//    /**
//     * 批量删除用户信息
//     *
//     * @param userIds 需要删除的用户ID
//     * @return 结果
//     */
//    public int deleteUserByIds(Long[] userIds);
//
//    /**
//     * 导入用户数据
//     *
//     * @param userList 用户数据列表
//     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
//     * @param operName 操作用户
//     * @return 结果
//     */
//    public String importUser(List<EUser> userList, Boolean isUpdateSupport, String operName);
//
//    /**
//     * 通过用户手机号查询用户
//     *
//     * @param phone 手机号
//     * @return 用户对象信息
//     */
//    EUser selectUserByPhone(String phone);

    /**
     * 通过用户手机号和appid查询用户
     *
     * @param phone 手机号
     * @return 用户对象信息
     */
    EUser selectUserByPhoneAndAppId(String phone, String appid);

    /**
     * 通过openid查询用户
     *
     * @param openid
     * @return 用户对象信息
     */
    EUserVO selectUserByWxopenid(String openid);
//
//    /**
//     * 检测用户是否有充值过押金
//     * @param userId
//     */
//    public Boolean checkIsDeposit(Long userId);
//
//    /**
//     * 新增用户
//     */
//    String getNewUser(String powerStart, String powerEnd,String areaId);
//
//    /**
//     * 总用户
//     */
//    String getTotalUser(String areaId);
//
//    /**
//     * 租赁用户
//     */
//    String getLeaseUser(String powerStart, String powerEnd,String areaId);
//
//    /**
//     * 绑定系统用户
//     */
//    int bandSystemUser(EUser user);
//
    /**
     * 实名认证
     *
     */
    Object authentication(AuthenticationQuery authenticationQuery);
//
//    /**
//     * 检测用户是否实名认证
//     * @param userId
//     * @return
//     */
//    boolean checkIsAuthentication(Long userId);
//
//    /**
//     * 根据手机号快速搜索用户列表
//     */
//    List<LabelVo> fastSearch(String phonenumber);

    /**
     * 修改用户密码
     */
    int updateUserPwd(Long userId, String newPassword);

    /**
     * 校验用户是否有数据权限
     *
     * @param userId 用户id
     */
    public void checkUserDataScope(Long userId);

    /**
     * 导入用户数据
     *
     * @param userList 用户数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importUser(List<EUser> userList, Boolean isUpdateSupport, String operName);

    /**
     * 校验用户名称是否唯一
     *
     * @param user 用户信息
     * @return 结果
     */
    public boolean checkUserNameUnique(EUser user);

    /**
     * 注册用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public boolean registerUser(EUser user);

    /**
     * 校验手机号码是否唯一
     *
     * @param user 用户信息
     * @return 结果
     */
    public boolean checkPhoneUnique(EUser user);

    /**
     * 校验email是否唯一
     *
     * @param user 用户信息
     * @return 结果
     */
    public boolean checkEmailUnique(EUser user);

    /**
     * 根据用户ID查询用户所属角色组
     *
     * @param userName 用户名
     * @return 结果
     */
    public String selectUserRoleGroup(String userName);

    /**
     * 根据用户ID查询用户所属岗位组
     *
     * @param userName 用户名
     * @return 结果
     */
    public String selectUserPostGroup(String userName);

    /**
     * 修改用户头像
     *
     * @param userName 用户名
     * @param avatar 头像地址
     * @return 结果
     */
    public boolean updateUserAvatar(String userName, String avatar);

    /**
     * 重置用户密码
     *
     * @param userName 用户名
     * @param password 密码
     * @return 结果
     */
    public int resetUserPwd(String userName, String password);


    /**
     * 校验用户是否允许操作
     *
     * @param user 用户信息
     */
    public void checkUserAllowed(EUser user);

    /**
     * 批量删除用户信息
     *
     * @param userIds 需要删除的用户ID
     * @return 结果
     */
    public int deleteUserByIds(Long[] userIds);

    /**
     * 重置用户密码
     *
     * @param user 用户信息
     * @return 结果
     */
    public int resetPwd(EUser user);

    /**
     * 用户授权角色
     *
     * @param userId 用户ID
     * @param roleIds 角色组
     */
    public void insertUserAuth(Long userId, Long[] roleIds);

    /**
     * 获取用户余额
     *
     * @param userId 用户id
     * @return 结果
     */
    BigDecimal selectUserBalanceById(Long userId);

    /**
     * 账变记录
     */
    List<EChangeBalance> myChangeBalanceList(EChangeBalanceQuery query, Long userId);

    /**
     * 管理员提现
     */
    int adminWithdraw(EWithdrawQuery withdraw);

    /**
     * 更新余额
     */
    int changeBalance(BigDecimal changeAmount, Long userId);

    /**
     *  根据运营商查商户列表
     */
    List<EUserVO> getMerchantList(EUserQuery userQuery);

    /**
     *  获取app用户信息(简化信息)
     */
    public EUserVO selectAppUserById(Long userId);

}
