package com.ruoyi.system.service.impl;

import java.util.Collections;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.EFeeRuleMapper;
import com.ruoyi.system.domain.rule.EFeeRule;
import com.ruoyi.system.domain.rule.EFeeRuleVO;
import com.ruoyi.system.domain.rule.EFeeRuleQuery;
import com.ruoyi.system.service.IEFeeRuleService;

/**
 * 收费模板Service业务层处理
 *
 * @author qzz
 * @date 2024-11-20
 */
@Service
public class EFeeRuleServiceImpl implements IEFeeRuleService
{
    @Autowired
    private EFeeRuleMapper eFeeRuleMapper;

    /**
     * 查询收费模板
     *
     * @param ruleId 收费模板主键
     * @return 收费模板
     */
    @Override
    public EFeeRuleVO selectEFeeRuleByRuleId(Long ruleId)
    {
        return eFeeRuleMapper.selectEFeeRuleByRuleId(ruleId);
    }

    /**
     * 查询收费模板列表
     *
     * @param eFeeRule 收费模板
     * @return 收费模板
     */
    @Override
    public List<EFeeRuleVO> selectEFeeRuleList(EFeeRuleQuery eFeeRule)
    {
        return eFeeRuleMapper.selectEFeeRuleList(eFeeRule);
    }

    /**
     * 新增收费模板
     *
     * @param eFeeRule 收费模板
     * @return 结果
     */
    @Override
    public int insertEFeeRule(EFeeRule eFeeRule)
    {
        eFeeRule.setCreateTime(DateUtils.getNowDate());
        return eFeeRuleMapper.insertEFeeRule(eFeeRule);
    }

    /**
     * 修改收费模板
     *
     * @param eFeeRule 收费模板
     * @return 结果
     */
    @Override
    public int updateEFeeRule(EFeeRule eFeeRule)
    {
        return eFeeRuleMapper.updateEFeeRule(eFeeRule);
    }

    /**
     * 批量删除收费模板
     *
     * @param ruleIds 需要删除的收费模板主键
     * @return 结果
     */
    @Override
    public int deleteEFeeRuleByRuleIds(Long[] ruleIds)
    {
        return eFeeRuleMapper.deleteEFeeRuleByRuleIds(ruleIds);
    }

    /**
     * 删除收费模板信息
     *
     * @param ruleId 收费模板主键
     * @return 结果
     */
    @Override
    public int deleteEFeeRuleByRuleId(Long ruleId)
    {
        return eFeeRuleMapper.deleteEFeeRuleByRuleId(ruleId);
    }

    /**
     * 根据房间id获取套餐
     */
    @Override
    public List<EFeeRuleVO> selectEFeeRuleListByRoomId(Long roomId) {
        return eFeeRuleMapper.selectEFeeRuleListByRoomId(roomId);
    }
}
