package com.ruoyi.system.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.area.EOperatingArea;
import com.ruoyi.system.domain.area.EOperatingAreaVO;
import com.ruoyi.system.mapper.EOperatingAreaMapper;
import com.ruoyi.system.service.IEOperatingAreaService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 运营区Service业务层处理
 *
 * @author qzz
 * @date 2024-09-18
 */
@Service
public class EOperatingAreaServiceImpl implements IEOperatingAreaService
{
    @Resource
    private EOperatingAreaMapper rlOperatingAreaMapper;

    /**
     * 查询运营区
     *
     * @param areaId 运营区主键
     * @return 运营区
     */
    @Override
    public EOperatingArea selectRlOperatingAreaByAreaId(Long areaId)
    {
        return rlOperatingAreaMapper.selectRlOperatingAreaByAreaId(areaId);
    }

    /**
     * 查询运营区
     *
     * @param agentId 运营区主键
     * @return 运营区
     */
    @Override
    public EOperatingAreaVO selectRlOperatingAreaByAgentId(Long agentId)
    {
        return rlOperatingAreaMapper.selectRlOperatingAreaByAgentId(agentId);
    }

    /**
     * 查询运营区列表
     *
     * @param rlOperatingArea 运营区
     * @return 运营区
     */
    @Override
    @DataScope(merchantAlias = "m", userAlias = "u")
    public List<EOperatingArea> selectRlOperatingAreaList(EOperatingArea rlOperatingArea)
    {
        return rlOperatingAreaMapper.selectRlOperatingAreaList(rlOperatingArea);
    }

    /**
     * 新增运营区
     *
     * @param rlOperatingArea 运营区
     * @return 结果
     */
    @Override
    public int insertRlOperatingArea(EOperatingArea rlOperatingArea)
    {
        rlOperatingArea.setCreateTime(DateUtils.getNowDate());
        return rlOperatingAreaMapper.insertRlOperatingArea(rlOperatingArea);
    }

    /**
     * 修改运营区
     *
     * @param rlOperatingArea 运营区
     * @return 结果
     */
    @Override
    public int updateRlOperatingArea(EOperatingArea rlOperatingArea)
    {
        return rlOperatingAreaMapper.updateRlOperatingArea(rlOperatingArea);
    }

    /**
     * 批量删除运营区
     *
     * @param areaIds 需要删除的运营区主键
     * @return 结果
     */
    @Override
    public int deleteRlOperatingAreaByAreaIds(Long[] areaIds)
    {
        return rlOperatingAreaMapper.deleteRlOperatingAreaByAreaIds(areaIds);
    }

    /**
     * 删除运营区信息
     *
     * @param areaId 运营区主键
     * @return 结果
     */
    @Override
    public int deleteRlOperatingAreaByAreaId(Long areaId)
    {
        return rlOperatingAreaMapper.deleteRlOperatingAreaByAreaId(areaId);
    }

    /**
     * 根据代理商id查询运营区id
     *
     * @param agentId 代理商id
     * @return 结果
     */
    @Override
    public Long selectAreaIdByAgentId(Long agentId) {
        return rlOperatingAreaMapper.selectAreaIdByAgentId(agentId);
    }
}
