package com.ruoyi.system.service.impl;

import java.util.Collections;
import java.util.List;

import com.ruoyi.system.device.service.DeviceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ERoomMapper;
import com.ruoyi.system.domain.room.ERoom;
import com.ruoyi.system.domain.room.ERoomVO;
import com.ruoyi.system.domain.room.ERoomQuery;
import com.ruoyi.system.service.IERoomService;

/**
 * 房间Service业务层处理
 *
 * @author qzz
 * @date 2024-11-20
 */
@Service
public class ERoomServiceImpl implements IERoomService
{
    @Autowired
    private ERoomMapper eRoomMapper;

    @Autowired
    private DeviceService smDeviceService;

    /**
     * 查询房间
     *
     * @param roomId 房间主键
     * @return 房间
     */
    @Override
    public ERoomVO selectERoomByRoomId(Long roomId)
    {
        return eRoomMapper.selectERoomByRoomId(roomId);
    }

    /**
     * 查询房间列表
     *
     * @param eRoom 房间
     * @return 房间
     */
    @Override
    public List<ERoomVO> selectERoomList(ERoomQuery eRoom)
    {
        return eRoomMapper.selectERoomList(eRoom);
    }

    /**
     * 根据店铺id查询房间列表
     *
     * @param storeId 店铺id
     * @return 房间集合
     */
    @Override
    public List<ERoomVO> selectERoomListByStoreId(Long storeId) {
        return eRoomMapper.selectERoomListByStoreId(storeId);
    }

    /**
     * 新增房间
     *
     * @param eRoom 房间
     * @return 结果
     */
    @Override
    public int insertERoom(ERoom eRoom)
    {
        return eRoomMapper.insertERoom(eRoom);
    }

    /**
     * 修改房间
     *
     * @param eRoom 房间
     * @return 结果
     */
    @Override
    public int updateERoom(ERoom eRoom)
    {
        return eRoomMapper.updateERoom(eRoom);
    }

    /**
     * 批量删除房间
     *
     * @param roomIds 需要删除的房间主键
     * @return 结果
     */
    @Override
    public int deleteERoomByRoomIds(Long[] roomIds)
    {
        return eRoomMapper.deleteERoomByRoomIds(roomIds);
    }

    /**
     * 删除房间信息
     *
     * @param roomId 房间主键
     * @return 结果
     */
    @Override
    public int deleteERoomByRoomId(Long roomId)
    {
        return eRoomMapper.deleteERoomByRoomId(roomId);
    }

    /**
     * 开门
     * @param roomId 房间id
     */
    @Override
    public boolean openGate(Long roomId) {
        ERoomVO eRoomVO = eRoomMapper.selectERoomByRoomId(roomId);
        return  smDeviceService.switchDevice(eRoomVO.getGateId(), true);
    }
}
