package com.ruoyi.system.service.impl;

import java.util.Collections;
import java.util.List;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.constant.ServiceConstants;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.EShareKeyMapper;
import com.ruoyi.system.domain.EShareKey;
import com.ruoyi.system.service.IEShareKeyService;

import javax.annotation.Resource;

/**
 * 共享钥匙Service业务层处理
 *
 * @author 邱贞招
 * @date 2024-07-31
 */
@Service
public class EShareKeyServiceImpl implements IEShareKeyService
{
    @Resource
    private EShareKeyMapper eShareKeyMapper;

    /**
     * 查询共享钥匙
     *
     * @param keyId 共享钥匙主键
     * @return 共享钥匙
     */
    @Override
    public EShareKey selectEShareKeyByKeyId(Long keyId)
    {
        return eShareKeyMapper.selectEShareKeyByKeyId(keyId);
    }

    /**
     * 查询共享钥匙列表
     *
     * @param eShareKey 共享钥匙
     * @return 共享钥匙
     */
    @Override
    @DataScope(merchantAlias = "m", userAlias = "u")
    public List<EShareKey> selectEShareKeyList(EShareKey eShareKey)
    {
        return eShareKeyMapper.selectEShareKeyList(eShareKey);
    }

    /**
     * 根据归属用户id查询共享钥匙列表
     *
     * @param ownerId 归属用户id
     * @return 共享钥匙集合
     */
    @Override
    public List<EShareKey> selectEShareKeyListByOwnerId(Long ownerId) {
        return eShareKeyMapper.selectEShareKeyListByOwnerId(ownerId);
    }

    /**
     * 根据归属用户id查询共享钥匙列表
     *
     * @param ownerId 归属用户id
     * @return 共享钥匙集合
     */
    @Override
    public List<EShareKey> selectExpiredEShareKeyListByOwnerId(Long ownerId) {
        return eShareKeyMapper.selectExpiredEShareKeyListByOwnerId(ownerId);
    }

    /**
     * 根据被分享用户id查询共享钥匙列表
     *
     * @param shareUserId 被分享用户id
     * @return 共享钥匙集合
     */
    @Override
    public List<EShareKey> selectEShareKeyListByShareUserId(Long shareUserId) {
        return eShareKeyMapper.selectEShareKeyListByShareUserId(shareUserId);
    }

    /**
     * 新增共享钥匙
     *
     * @param eShareKey 共享钥匙
     * @return 结果
     */
    @Override
    public int insertEShareKey(EShareKey eShareKey)
    {
        eShareKey.setStatus(ServiceConstants.KEY_STATUS_NEW);
        if(StrUtil.isBlank(eShareKey.getKeyName())){
            eShareKey.setKeyName("共享钥匙"+eShareKey.getSn());
        }
        return eShareKeyMapper.insertEShareKey(eShareKey);
    }

    /**
     * 修改共享钥匙
     *
     * @param eShareKey 共享钥匙
     * @return 结果
     */
    @Override
    public int updateEShareKey(EShareKey eShareKey)
    {
        return eShareKeyMapper.updateEShareKey(eShareKey);
    }

    /**
     * 批量删除共享钥匙
     *
     * @param keyIds 需要删除的共享钥匙主键
     * @return 结果
     */
    @Override
    public int deleteEShareKeyByKeyIds(Long[] keyIds)
    {
        return eShareKeyMapper.deleteEShareKeyByKeyIds(keyIds);
    }

    /**
     * 删除共享钥匙信息
     *
     * @param keyId 共享钥匙主键
     * @return 结果
     */
    @Override
    public int deleteEShareKeyByKeyId(Long keyId)
    {
        return eShareKeyMapper.deleteEShareKeyByKeyId(keyId);
    }
}
