package com.ruoyi.system.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.withdraw.EWithdraw;
import com.ruoyi.system.domain.withdraw.EWithdrawVO;
import com.ruoyi.system.mapper.EWithdrawMapper;
import com.ruoyi.system.service.IEWithdrawService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;

/**
 * 提现记录Service业务层处理
 *
 * @author qzz
 * @date 2024-09-28
 */
@Service
public class EWithdrawServiceImpl implements IEWithdrawService
{
    @Autowired
    private EWithdrawMapper rlWithdrawMapper;

    /**
     * 查询提现记录
     *
     * @param id 提现记录主键
     * @return 提现记录
     */
    @Override
    public EWithdrawVO selectRlWithdrawById(Long id)
    {
        return rlWithdrawMapper.selectRlWithdrawById(id);
    }

    /**
     * 查询提现记录列表
     *
     * @param rlWithdraw 提现记录
     * @return 提现记录
     */
    @Override
    @DataScope(merchantAlias = "u")
    public List<EWithdraw> selectRlWithdrawList(EWithdraw rlWithdraw)
    {
        return rlWithdrawMapper.selectRlWithdrawList(rlWithdraw);
    }

    /**
     * 新增提现记录
     *
     * @param rlWithdraw 提现记录
     * @return 结果
     */
    @Override
    public int insertRlWithdraw(EWithdraw rlWithdraw)
    {
        rlWithdraw.setCreateTime(DateUtils.getNowDate());
        return rlWithdrawMapper.insertRlWithdraw(rlWithdraw);
    }

    /**
     * 修改提现记录
     *
     * @param rlWithdraw 提现记录
     * @return 结果
     */
    @Override
    public int updateRlWithdraw(EWithdraw rlWithdraw)
    {
        return rlWithdrawMapper.updateRlWithdraw(rlWithdraw);
    }

    /**
     * 批量删除提现记录
     *
     * @param ids 需要删除的提现记录主键
     * @return 结果
     */
    @Override
    public int deleteRlWithdrawByIds(Long[] ids)
    {
        return rlWithdrawMapper.deleteRlWithdrawByIds(ids);
    }

    /**
     * 删除提现记录信息
     *
     * @param id 提现记录主键
     * @return 结果
     */
    @Override
    public int deleteRlWithdrawById(Long id)
    {
        return rlWithdrawMapper.deleteRlWithdrawById(id);
    }

    /**
     * 累计提现金额
     *
     * @param RlUserId 用户id
     * @return 结果
     */
    @Override
    public BigDecimal cumulativeWithdrawalAmount(Long RlUserId) {
        return rlWithdrawMapper.cumulativeWithdrawalAmount(RlUserId);
    }
}
